@@ -21,7 +21,7 @@ seconds_in_hour = 3600
 seconds_in_half_hour = 1800
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.8.1'
+jaws_version = '0.8.2'
 
 ###############################################################################
 
@@ -154,6 +154,10 @@ def load_dataset_attributes(name, ds, args, **kwargs):
                         pass
                     else:
                         ds[key1].attrs = value2.items()
+    if args.celsius:
+        temperature_vars = kwargs.pop('temperature_vars')
+        for var in temperature_vars:
+            ds[var].attrs.update([('units', 'celsius')])
     for column in columns:
         if column in ('qc1', 'qc9', 'qc17', 'qc25'):
             load_dataset_attributes_gcnet_qltyctrl(name, ds)
